%define  name 		unh_iscsi
%define  version	1.6
%define  release	00
%define	 iscsidir	/opt/unh/iscsi

Summary:	UNH iSCSI Initiator/Target for Linux
Name: 		%{name}
Version: 	%{version}
Release: 	%{release}
Vendor: 	University of New Hampshire Interoperability Labs (UNH IOL)
URL: 		http://www.iol.unh.edu/consortiums/iscsi/
License: 	GPL
Group: 		System Environment/Kernel
Source0: 	%{name}-%{version}.%{release}.tar.bz2
Patch0: 	%{name}-%{version}.%{release}.diff
BuildRoot:	/var/tmp/%{name}-buildroot
ExclusiveOS:	linux
ExclusiveArch:	i386 i586 i686

Packager:	Matthias G. Eckermann <mge@suse.de>
Distribution:	SuSE SLES-9 (i586) Addon

%description
The UNH-iSCSI project consists of software implementations of an
initiator and a target emulator for the IETF iSCSI Storage Area
Networking (SAN) protocol (Draft 20).

%prep
/bin/rm -rf ${RPM_BUILD_DIR}/file.list.%{name} ${RPM_BUILD_DIR}/%{name}

%setup -n unh_iscsi.%{version}.%{release}
%patch0 -p 1

#
#	BUILD
#
%build

mv src/* .

echo "#This file created by rpmbuild prior to the install step" > initiator/RPM
echo "%{name}-%{version}-%{release}" >> initiator/RPM

/usr/bin/make clean iscsi

#
#	INSTALL
#
%install
if [ -n "$RPM_BUILD_ROOT" ] ; then
   [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
fi

# Initialize variables
ISCSI_CMDS="iscsi_config iscsi_manage iscsi_test iscsi_rebuild iscsi_connect iscsi_mount iscsi_umount iscsi_disconnect"
ISCSI_DOCS="COPYING README.initiator README.target ENTRY-POINTS-INI ISCSI_CONFIG ISCSI_MANAGE OVERVIEW OVERVIEW-FFP OVERVIEW-INI OVERVIEW-INI-SCSI README.CONFIG CHANGELOG"
ISCSI_MAN="iscsi_manage.8 iscsi_config.8"

UNH_ISCSI_DIR=%{iscsidir}
UNH_ISCSI_MOD=${UNH_ISCSI_DIR}/modules
UNH_ISCSI_BIN=${UNH_ISCSI_DIR}/bin
UNH_ISCSI_SRC=${UNH_ISCSI_DIR}/src
UNH_ISCSI_LOG=/var/${UNH_ISCSI_DIR}/logs
UNH_ISCSI_CONF=/etc/${UNH_ISCSI_DIR}/conf
UNH_ISCSI_DEV=/var/${UNH_ISCSI_DIR}/dev

# Create the necessary directories
for dir in ${UNH_ISCSI_BIN} ${UNH_ISCSI_MOD} ${UNH_ISCSI_SRC} ${UNH_ISCSI_LOG} ${UNH_ISCSI_CONF} ${UNH_ISCSI_DEV} docs
do
	/bin/mkdir -p ${RPM_BUILD_ROOT}/${dir}
done
echo "%dir ${UNH_ISCSI_LOG}" >> ${RPM_BUILD_DIR}/file.list.%{name}
echo "%dir ${UNH_ISCSI_DEV}" >> ${RPM_BUILD_DIR}/file.list.%{name}

# Copy the startup script
/bin/mkdir -p ${RPM_BUILD_ROOT}/etc/init.d
/bin/cp cmd/iscsi_init ${RPM_BUILD_ROOT}/etc/init.d/unh_iscsi
/bin/chmod +x ${RPM_BUILD_ROOT}/etc/init.d/unh_iscsi
echo "/etc/init.d/unh_iscsi" >> ${RPM_BUILD_DIR}/file.list.%{name}

# Copy the sample configuration files
/bin/cp scripts/fstab.iscsi.sample ${RPM_BUILD_ROOT}/${UNH_ISCSI_CONF}
/bin/cp scripts/target.sample ${RPM_BUILD_ROOT}/${UNH_ISCSI_CONF}
/bin/cp scripts/target.sample.chap ${RPM_BUILD_ROOT}/${UNH_ISCSI_CONF}
/bin/cp scripts/target.sample.srp  ${RPM_BUILD_ROOT}/${UNH_ISCSI_CONF}
/bin/chmod -x ${RPM_BUILD_ROOT}/${UNH_ISCSI_CONF}/target.sample

echo "${UNH_ISCSI_CONF}/fstab.iscsi.sample" >>  ${RPM_BUILD_DIR}/file.list.%{name}
echo "${UNH_ISCSI_CONF}/target.sample" >>  ${RPM_BUILD_DIR}/file.list.%{name}
echo "${UNH_ISCSI_CONF}/target.sample.chap" >>  ${RPM_BUILD_DIR}/file.list.%{name}
echo "${UNH_ISCSI_CONF}/target.sample.srp" >>  ${RPM_BUILD_DIR}/file.list.%{name}

# Copy the Initiator and Target modules
#
# Decide which drivers to copy .
# In 2.6.0, the drivers have a suffize of .ko and
# are located at the src/ level while the
# 2.4.x drivers are located with the initiator or target directories.
#
if [ -f unh_iscsi_initiator.ko ]
# We have 2.6.0 drivers
then
	MOD_DIR=/lib/modules/2.6.5-override-default/
	/bin/mkdir -p ${RPM_BUILD_ROOT}/${MOD_DIR}
	/bin/cp unh_iscsi_initiator.ko ${RPM_BUILD_ROOT}/${MOD_DIR}
	/bin/cp unh_iscsi_target.ko ${RPM_BUILD_ROOT}/${MOD_DIR}
	/bin/cp unh_scsi_target.ko ${RPM_BUILD_ROOT}/${MOD_DIR}
	echo "${MOD_DIR}/unh_iscsi_initiator.ko" >> ${RPM_BUILD_DIR}/file.list.%{name}
	echo "${MOD_DIR}/unh_iscsi_target.ko" >> ${RPM_BUILD_DIR}/file.list.%{name}
	echo "${MOD_DIR}/unh_scsi_target.ko" >> ${RPM_BUILD_DIR}/file.list.%{name}
# 2.4.x drivers
else
	KERNEL_VER=`uname -r`
	MOD_DIR=${UNH_ISCSI_MOD}/${KERNEL_VER}
	/bin/mkdir -p ${RPM_BUILD_ROOT}/${MOD_DIR}
	/bin/cp initiator/unh_iscsi_initiator.o ${RPM_BUILD_ROOT}/${MOD_DIR}
	/bin/cp target/unh_iscsi_target.o ${RPM_BUILD_ROOT}/${MOD_DIR}
	/bin/cp target/unh_scsi_target.o ${RPM_BUILD_ROOT}/${MOD_DIR}
	echo "${MOD_DIR}/unh_iscsi_initiator.o" >> ${RPM_BUILD_DIR}/file.list.%{name}
	echo "${MOD_DIR}/unh_iscsi_target.o" >> ${RPM_BUILD_DIR}/file.list.%{name}
	echo "${MOD_DIR}/unh_scsi_target.o" >> ${RPM_BUILD_DIR}/file.list.%{name}
fi

# Copy the iSCSI commands
for cmd in $ISCSI_CMDS
do
	/bin/cp cmd/${cmd} ${RPM_BUILD_ROOT}/${UNH_ISCSI_BIN}
	echo "${UNH_ISCSI_BIN}/${cmd}" >> ${RPM_BUILD_DIR}/file.list.%{name}
	/bin/chmod 0744 ${RPM_BUILD_ROOT}/${UNH_ISCSI_BIN}/${cmd}
done

#
#	???
#
# Copy the source
#/usr/bin/make clean
#/bin/cp -R . ${RPM_BUILD_ROOT}/${UNH_ISCSI_SRC}
#
#/usr/bin/find . -type f -printf "${UNH_ISCSI_SRC}/%p\n" >> ${RPM_BUILD_DIR}/file.list.%{name}
#

# Copy the man pages
UNH_ISCSI_MAN=/usr/share/man/man8
/bin/mkdir -p ${RPM_BUILD_ROOT}/${UNH_ISCSI_MAN}
for man in ${ISCSI_MAN}
do
	/bin/cp docs/${man} ${RPM_BUILD_ROOT}/${UNH_ISCSI_MAN}
	/bin/gzip -f ${RPM_BUILD_ROOT}/${UNH_ISCSI_MAN}/${man}
	echo "${UNH_ISCSI_MAN}/${man}.gz"  >> ${RPM_BUILD_DIR}/file.list.%{name}
done

# Copy the documents
/bin/cp initiator/README docs/README.initiator
/bin/cp target/README docs/README.target
/bin/cp CHANGELOG docs/CHANGELOG
/bin/cp COPYING docs/COPYING

for doc in $ISCSI_DOCS
do
	echo "%doc docs/${doc}" >> ${RPM_BUILD_DIR}/file.list.%{name}
done


#
#	CLEAN
#
%clean
if [ -n "$RPM_BUILD_ROOT" ] ; then
   [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
fi



#
#	PRE
#
%pre
#!/bin/sh

# Check if a module is already loaded
check_loaded()
{
	MODULE=$1
	LOADED="`/sbin/lsmod | /bin/grep -cw ${MODULE}`"
	# Nothing to do if module is already loaded
	[ "$LOADED" -gt 0 ] && return 0
	return 1
}

# Don't allow any upgrade
if [ $1 -eq 2 -o -x /etc/init.d/unh_iscsi ]
then
	echo "This release of unh_iscsi cannot be upgraded."
	echo "Please remove the installed 'unh_iscsi' RPM before upgrading"
	echo "to this release. Use 'rpm -e unh_iscsi' to remove."
	exit 1
fi

# Don't allow upgrade (another check)
check_loaded unh_iscsi_initiator
if [ $? -eq 0 ] 
then
	echo
	echo "Upgrade failed: UNH iSCSI Initiator module can not be unloaded."
	echo "This release of unh_iscsi cannot be upgraded."
	echo "Please remove the installed 'unh_iscsi' RPM before upgrading"
	echo "to this release. Use 'rpm -e unh_iscsi' to remove."
	echo
	exit 1
fi

# Remove old installation modules, devices & logs
#
#	NO! (mge@suse.de, 20050414)
#
# /bin/rm -rf %{iscsidir}/src >/dev/null 2>&1
# /bin/rm -rf %{iscsidir}/logs >/dev/null 2>&1
# /bin/rm -rf %{iscsidir}/modules >/dev/null 2>&1
# /bin/rm -rf %{iscsidir}/dev >/dev/null 2>&1

exit 0


#
#	POST
#
#%post
#
#sync
#
#cat <<EOF
#
# The %{name} package has been installed successfully. For more information
# about this driver, please read %{_docdir}/%{name}/README or
#  %{_docdir}/%{name}-%{version}/README (depending on your distribution).
#
#EOF
#
#cver=`chkconfig  --version | grep -c version`
#
#if [ $cver -ne 0 ]
#then
#	# chkconfig is present
#	chkconfig --del unh_iscsi
#	chkconfig --add unh_iscsi
#else
#	for runlevel in 2 3 4 5
#	do
#		if [ -f /etc/rc.config ]
#		then
#			dir=/etc/init.d/rc${runlevel}.d # SuSE
#		else
#			dir/etc/rc.d/rc${runlevel}.d   # RedHat
#		fi
#		ln -sf /etc/init.d/unh_iscsi ${dir}/S10unh_iscsi
#		ln -sf /etc/init.d/unh_iscsi ${dir}/K15unh_iscsi
#	done > /dev/null
#fi
#
## Load and start the driver
#/bin/sh /etc/init.d/unh_iscsi start
#
#exit 0
#

#
#	PREUN
#
%preun
sync

# Check if a module is already loaded
check_loaded()
{
	MODULE=$1
	LOADED="`/sbin/lsmod | /bin/grep -cw ${MODULE}`"
	# Nothing to do if module is already loaded
	[ "$LOADED" -gt 0 ] && return 0
	return 1
}

echo

echo "Removing %{name} package. Please wait..."
echo "Stopping the %{name} driver.... "

echo " "
# Unload the driver
/bin/sh /etc/init.d/unh_iscsi stop

check_loaded unh_iscsi
if [ $? -eq 0 ]
then
	echo "ERROR: Uninstall failed: UNH iSCSI Initiator module can not be unloaded."
	echo
	exit 1
else
	echo
fi

#rm -f /dev/unh_iscsi_initiator
#cver=`/sbin/chkconfig  --version | grep -c version`
#if [ $cver -ne 0 ]
#then
#	/sbin/chkconfig --del unh_iscsi
#else
#	for runlevel in 0 1 2 3 4 5 6
#	do
#		if [ -f /etc/rc.config ]
#		then
#			dir=/etc/init.d/rc${runlevel}.d  # SuSE
#		else
#			dir=/etc/rc.d/rc${runlevel}.d    # RedHat
#		fi
#		/bin/rm -rf ${dir}/S10unh_iscsi ${dir}/K15unh_iscsi
#	done > /dev/null
#fi
#

#
#	POSTUN
#
#%postun
#sync
#
## Remove installation modules, devices & logs
#/bin/rm -rf %{iscsidir}/src >/dev/null 2>&1
#/bin/rm -rf %{iscsidir}/logs >/dev/null 2>&1
#/bin/rm -rf %{iscsidir}/modules >/dev/null 2>&1
#/bin/rm -rf %{iscsidir}/dev >/dev/null 2>&1
#
#echo "The %{name} package has been removed successfully."
#echo " "
#exit 0


#
#	FILES
#

%files -f ../file.list.%{name}
%defattr(-,root,root)
